==> cpg-1.1-sources.jar: de/fraunhofer/aisec/cpg/passes/scopes/FunctionScope.java <==
/*
 * Copyright (c) 2019, Fraunhofer AISEC. All rights reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *                    $$$$$$\  $$$$$$$\   $$$$$$\
 *                   $$  __$$\ $$  __$$\ $$  __$$\
 *                   $$ /  \__|$$ |  $$ |$$ /  \__|
 *                   $$ |      $$$$$$$  |$$ |$$$$\
 *                   $$ |      $$  ____/ $$ |\_$$ |
 *                   $$ |  $$\ $$ |      $$ |  $$ |
 *                   \$$$$$   |$$ |      \$$$$$   |
 *                    \______/ \__|       \______/
 *
 */

package de.fraunhofer.aisec.cpg.passes.scopes;

import de.fraunhofer.aisec.cpg.graph.FunctionDeclaration;
import de.fraunhofer.aisec.cpg.graph.Node;
import de.fraunhofer.aisec.cpg.graph.Type;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class FunctionScope extends DeclarationScope {

  private Map<Type, List<Node>> catchesOrRelays = new HashMap<>();

  public FunctionScope(FunctionDeclaration astNode) {
    super(astNode);
  }

  public Map<Type, List<Node>> getCatchesOrRelays() {
    return catchesOrRelays;
  }

  public void setCatchesOrRelays(Map<Type, List<Node>> catchesOrRelays) {
    this.catchesOrRelays = catchesOrRelays;
  }
}

==> cpg-1.3.1-sources.jar: de/fraunhofer/aisec/cpg/passes/scopes/FunctionScope.java <==
/*
 * Copyright (c) 2019, Fraunhofer AISEC. All rights reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *                    $$$$$$\  $$$$$$$\   $$$$$$\
 *                   $$  __$$\ $$  __$$\ $$  __$$\
 *                   $$ /  \__|$$ |  $$ |$$ /  \__|
 *                   $$ |      $$$$$$$  |$$ |$$$$\
 *                   $$ |      $$  ____/ $$ |\_$$ |
 *                   $$ |  $$\ $$ |      $$ |  $$ |
 *                   \$$$$$   |$$ |      \$$$$$   |
 *                    \______/ \__|       \______/
 *
 */

package de.fraunhofer.aisec.cpg.passes.scopes;

import de.fraunhofer.aisec.cpg.graph.FunctionDeclaration;
import de.fraunhofer.aisec.cpg.graph.Node;
import de.fraunhofer.aisec.cpg.graph.Type;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.checkerframework.checker.nullness.qual.NonNull;

public class FunctionScope extends DeclarationScope {
  @NonNull private Map<Type, List<Node>> catchesOrRelays = new HashMap<>();

  public FunctionScope(FunctionDeclaration astNode) {
    super(astNode);
  }

  @NonNull
  public Map<Type, List<Node>> getCatchesOrRelays() {
    return catchesOrRelays;
  }

  public void setCatchesOrRelays(@NonNull Map<Type, List<Node>> catchesOrRelays) {
    this.catchesOrRelays = catchesOrRelays;
  }
}
